@@ -6,14 +6,22 @@
  * mpage:	a program to reduce pages of print so that several pages
  * 	  	of output appear on one printed page.
  *
- * Copyright (c) 1994-1999 Marcel J.E. Mol, The Netherlands
+ * Copyright (c) 1994-2004 Marcel J.E. Mol, The Netherlands
  * Copyright (c) 1988 Mark P. Hahn, Herndon, Virginia
  *  
- *     Permission is granted to anyone to make or distribute verbatim
- *     copies of this document as received, in any medium, provided
- *     that this copyright notice is preserved, and that the
- *     distributor grants the recipient permission for further
- *     redistribution as permitted by this notice.
+ *     This program is free software; you can redistribute it and/or
+ *     modify it under the terms of the GNU General Public License
+ *     as published by the Free Software Foundation; either version 2
+ *     of the License, or (at your option) any later version.
+ *
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ *
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program; if not, write to the Free Software
+ *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -43,6 +51,7 @@ struct page_desc paper[] = {
     { "Legal",        612, 1008 },
     { "Statement",    396,  612 },
     { "Executive",    540,  720 },
+    { "A0",           2384, 3368 },  /* 840 x 1188 mm */
     { "A1",           1684, 2384 },  /* 594 x 840 mm */
     { "A2",           1192, 1684 },  /* 420 x 594 mm */
 /*    { "A3",           842, 1190 }, */
@@ -341,11 +350,11 @@ int opt_first[MAXJARG];           /* start with first sheet per -j */
 int opt_last[MAXJARG];         	  /* print as many as supplied per -j */
 int opt_alt[MAXJARG];             /* by default print all sheets, odd+even per -j*/
 int opt_file          = 1;        /* should each file appera on a new sheet */
-int opt_duplex        = 0;        /* duplex mode flag */
+int opt_duplex        = DEFAULT_DUPLEX;  /* duplex mode flag */
 int opt_tumble        = 0;        /* tumble overy second pages */
 int opt_textbox       = 0;        /* don't normally draw box around text */
 int opt_input         = IN_AUTO;  /* select input file format */
-int opt_encoding      = DEFAULT_ENCODING;	/* use default encoding or not */
+int opt_encoding      = DEFAULT_ENCODING; /* use default encoding or not */
 struct pagebox textbox = {0, 0, 80, 66, 0};
 
 char * opt_header = NULL;      /* the header for pr's -h option */
@@ -374,6 +383,8 @@ int last_encoding;	/* last encoding in character set */
 
 /* GPN. for coli */
 int Coli = 0;           /* value of 0 = don't mess, 1 = 4, 1 (outside pages)*/
+int use_utf8 = 0;       /* is input UTF-8 or not. */
+int check_utf8 = 1;     /* do we want to check for UTF-8 or not. */
 
 
 
@@ -381,9 +392,9 @@ void usage(int errcode)
 {
     fprintf(stderr, "\
  mpage - print multiple pages on postscript, version %s\n\n\
- mpage [-1248acEfHlkoOrRStvxX] [-b papersize] [-Btextboxmargin]\n\
+ mpage [-1248aceEfHlkoOrRStTvuVxX] [-b papersize] [-Btextboxmargin]\n\
        [-C [encodingfile]] [-da|p] [-D dateformat] [-F fontname]\n\
-       [-h header] [-I indent] [-j pagespec] [-L lines]\n\
+       [-h header] [-I indent] [-j pagespec] [-J startpageno] [-L lines]\n\
        [-msheetmargin] [-Mpagemargin] [-p[prprog]] [-P[printer]]\n\
        [-s tabstop] [-W width] [-X [header]] [-z printcmd] [-Z quearg]\n\
        [file...]]\n",
@@ -396,10 +407,11 @@ void usage(int errcode)
  -a Toggle across/updown layout (u)	-l Toggle portrait/landscape (p)\n\
  -f Toggle folding long lines (off)	-o Toggle printing outlines (on)\n\
  -r Reverse printing, last->first sheet	-v Toggle verbose output, (on)\n\
- -F Text font to be used (Courier)      -C Character encoding filename\n\
+ -F Text font to be used (%s)      -C Character encoding filename\n\
  -E Print every second and third page   -O Print every first and fourth page\n\
  -s Define tabstop width (%d)            -k kill on %%TRailer is PS file\n\
- -b papersize (%s), use l of ? to get a list of sizes\n\
+ -V Show mpage version.\n               -u switch of utf-8 check\n\
+ -b papersize (%s), use l or ? to get a list of sizes\n\
  -R Switch to across mode, with first page at lower left corner\n\
  -H Create page header for each page for text files\n\
  -X Print physical page header (filename + physical pagenumber)\n\
@@ -415,11 +427,13 @@ void usage(int errcode)
  -Z Specify print command print queue option (%s).\n\
  -j Print specified sheets: first[-last][%%interval]\n\
     -j 1-10 does first 10 sheets, -j 1%%2 prints odd ones, -j 2%%2 even ones.\n\
- -t Toggle printing both sides of the paper (Duplex mode, off)\n\
+ -J Set the start of the sheet page count\n\
+ -t Toggle printing both sides of the paper (Duplex mode, %s)\n\
  -T Toggle tumble of every second pages when printing in duplex mode (off)\n",
-    opt_tabstop, PAGE_DEF, printprog, printarg
+    fontname, opt_tabstop, PAGE_DEF, printprog, printarg,
+    opt_duplex ? "on" : "off"
     );
-    fprintf(stderr, "\n(c) 1993-2002 Marcel Mol, marcel@mesa.nl (MESA Consulting)\n");
+    fprintf(stderr, "\n(c) 1993-2005 Marcel Mol, marcel@mesa.nl (MESA Consulting)\n");
 
     return;
 
