@@ -9,11 +9,19 @@
  * Copyright (c) 1994-2004 Marcel J.E. Mol, The Netherlands
  * Copyright (c) 1988 Mark P. Hahn, Herndon, Virginia
  *  
- *     Permission is granted to anyone to make or distribute verbatim
- *     copies of this document as received, in any medium, provided
- *     that this copyright notice is preserved, and that the
- *     distributor grants the recipient permission for further
- *     redistribution as permitted by this notice.
+ *     This program is free software; you can redistribute it and/or
+ *     modify it under the terms of the GNU General Public License
+ *     as published by the Free Software Foundation; either version 2
+ *     of the License, or (at your option) any later version.
+ *
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ *
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program; if not, write to the Free Software
+ *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -54,6 +62,11 @@ char **argv;
     _wildcard (&argc, &argv);
 #endif
 
+    /*
+     * Check page size for /etc/papersize
+     */
+    check_papersize();
+
     /*
      * examine the environment for PRINTER (or LPDEST) and MPAGE
      * environment variables
