@@ -9,12 +9,19 @@
  * Copyright (c) 1994-2004 Marcel J.E. Mol, The Netherlands
  * Copyright (c) 1988 Mark P. Hahn, Herndon, Virginia
  *  
+ *     This program is free software; you can redistribute it and/or
+ *     modify it under the terms of the GNU General Public License
+ *     as published by the Free Software Foundation; either version 2
+ *     of the License, or (at your option) any later version.
  *
- *     Permission is granted to anyone to make or distribute verbatim
- *     copies of this document as received, in any medium, provided
- *     that this copyright notice is preserved, and that the
- *     distributor grants the recipient permission for further
- *     redistribution as permitted by this notice.
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ *
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program; if not, write to the Free Software
+ *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -31,7 +38,7 @@
 #include <limits.h>
 #include <string.h>
 
-#define	VERSION		"2.5.5 November 2006"
+#define	VERSION		"2.5.7 June 2017"
 
 #define	TRUE		1
 #define	FALSE		0
@@ -340,6 +347,7 @@ void do_sheets();
 /* glob.c */
 void usage();
 /* page.c */
+void check_papersize();
 void set_page();
 int select_pagetype();
 void show_pagetypes();
