@@ -6,14 +6,22 @@
  * mpage:    a program to reduce pages of print so that several pages
  *           of output appear on one printed page.
  *
- * Copyright (c) 1994-1999 Marcel J.E. Mol, The Netherlands
+ * Copyright (c) 1994-2004 Marcel J.E. Mol, The Netherlands
  * Copyright (c) 1988 Mark P. Hahn, Herndon, Virginia
  *  
- *     Permission is granted to anyone to make or distribute verbatim
- *     copies of this document as received, in any medium, provided
- *     that this copyright notice is preserved, and that the
- *     distributor grants the recipient permission for further
- *     redistribution as permitted by this notice.
+ *     This program is free software; you can redistribute it and/or
+ *     modify it under the terms of the GNU General Public License
+ *     as published by the Free Software Foundation; either version 2
+ *     of the License, or (at your option) any later version.
+ *
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ *
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program; if not, write to the Free Software
+ *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -356,7 +364,11 @@ ps_copyprolog(fd, outfd)
 
     Debug(DB_PSDOC, "%%ps_copyprolog: adding mpage prolog\n", 0);
     if (!have_showsheet) {
+#if 1
+        fprintf(outfd, "/showsheet  /showpage load def\n");
+#else
         fprintf(outfd, "/showsheet { showpage } bind def\n");
+#endif
         fprintf(outfd, "/showpage { } def\n");
         have_showsheet = 1;
     }
@@ -723,16 +735,16 @@ do_post_sheet(fd, asheet, outfd)
          * Take extra page margins into account
          */
         fprintf(outfd, "%d %d div %d %d div scale\n",
-               ps_width - pagemargin_left - pagemargin_right, ps_width,
-               ps_height - pagemargin_top - pagemargin_bottom, ps_height);
+               ps_width, ps_width + pagemargin_left + pagemargin_right,
+               ps_height, ps_height + pagemargin_top + pagemargin_bottom);
 #ifndef NSCALE
         fprintf(outfd, "%d %d translate\n", pagemargin_left, pagemargin_bottom);
 #endif
 
 #if 0
-   /* does not seem to be neccessary. seems to create dictionary
-      stack underflows...
-    */
+        /* does not seem to be neccessary. seems to create dictionary
+         * stack underflows...
+         */
         if ((ps_posttype == PS_TEX || ps_posttype == PS_TEX2) && tex1)
             /* start dvi2ps init every page */
 	    fprintf(outfd, "%s%s", tex1, tex2);
@@ -756,7 +768,7 @@ do_post_sheet(fd, asheet, outfd)
             points++;
         }
         /*
-         * clean up after mpage as drawn its page
+         * clean up after mpage has drawn its page
          */
         fprintf(outfd, "grestore\n");
       }
@@ -860,16 +872,16 @@ do_post_sheet(fd, asheet, outfd)
          * Take extra page margins into account
          */
         fprintf(outfd, "%d %d div %d %d div scale\n",
-               ps_width - pagemargin_left - pagemargin_right, ps_width,
-               ps_height - pagemargin_top - pagemargin_bottom, ps_height);
+               ps_width, ps_width + pagemargin_left + pagemargin_right,
+               ps_height, ps_height + pagemargin_top + pagemargin_bottom);
 #ifndef NSCALE
         fprintf(outfd, "%d %d translate\n", pagemargin_left, pagemargin_bottom);
 #endif
 
 #if 0
-   /* does not seem to be neccessary. seems to create dictionary
-      stack underflows...
-    */
+        /* does not seem to be neccessary. seems to create dictionary
+         * stack underflows...
+         */
         if ((ps_posttype == PS_TEX || ps_posttype == PS_TEX2) && tex1)
             /* start dvi2ps init every page */
 	    fprintf(outfd, "%s%s", tex1, tex2);
@@ -890,16 +902,16 @@ do_post_sheet(fd, asheet, outfd)
          * clean up after mpage as drawn its page
          */
         fprintf(outfd, "grestore\n");
-      }
 #if 0
-      fprintf(outfd, "sheetsave restore\n");
+        fprintf(outfd, "sheetsave restore\n");
 #endif
 
-      /*
-       * print the sheet
-       */
-      if (points->pp_origin_x == 0 || (rtn_val == FILE_EOF && opt_file))
-          fprintf(outfd, "showsheet\n");
+        /*
+         * print the sheet
+         */
+        if (points->pp_origin_x == 0 || (rtn_val == FILE_EOF && opt_file))
+            fprintf(outfd, "showsheet\n");
+      }
 
     /*
      * let the upper level know about the status of possible EOF
@@ -1010,65 +1022,67 @@ post_one_line(line, fd, outfd, indoc, flush_page)
  int flush_page;
 {
         if (strncmp(line, "%%BeginDocument", 15) == 0) {
-            *indoc = 1;
+            (*indoc)++;
         }
         if (strncmp(line, "%%EndDocument", 13) == 0) {
-            *indoc = 0;
+            (*indoc)--;
         }
-        if (!*indoc && strncmp(line, "%%Page:", 7) == 0) {
-            fprintf(outfd, "%% %s", line);
-            /*
-             * only if there is already output to this logical page
-             */
-            if (!plcnt)
-                return FILE_CONT;
-            Debug(DB_PSROFF, "%%post_one_line: next page\n", 0);
-            return FILE_MORE;
-        }
-        if (opt_killtrail && (strncmp(line, "%%Trailer", 9) == 0 ||
-            strncmp(line, "%%PSTrailer", 11) == 0)) {
-            fprintf(outfd, "%% %s", line);
-            Debug(DB_PSROFF, "%%post_one_line: found trailer\n", 0);
-            ps_at_trailer = TRUE;
-            return FILE_EOF;
-        }
-        /* For netscape output */
-        if (strncmp(line, "%%EOF", 5) == 0) {
-            fprintf(outfd, "%% %s", line);
-            Debug(DB_PSROFF, "%%post_one_line: Netscape EOF\n", 0);
-            return FILE_EOF;
-        }
-        if (ps_posttype == PS_MPAGE && strncmp(line, "showsheet", 9) == 0)
-            return FILE_CONT;
-        if (ps_posttype == PS_TEX || ps_posttype == PS_TEX2) {
-            if (ps_posttype == PS_TEX2 &&
-                (strstr(line, "eop\n") || strstr(line, "eop end\n"))) {
-                fprintf(outfd, "%s", line);
-                Debug(DB_PSROFF, "%%post_one_line: found TEX eop\n", 0);
+	if (!*indoc) {
+            if (strncmp(line, "%%Page:", 7) == 0) {
+                fprintf(outfd, "%% %s", line);
+                /*
+                 * only if there is already output to this logical page
+                 */
+                if (!plcnt)
+                    return FILE_CONT;
+                Debug(DB_PSROFF, "%%post_one_line: next page\n", 0);
                 return FILE_MORE;
             }
-            if (strncmp(line, "TeXDict", 7) == 0) {
-                /*
-                 * Hope all dvi2ps progs work the same:
-                 * capture the TeX init code so we can run it 'manually' for
-                 * every page. This is needed as this code sets up a gstate 
-                 * that conflicts with mpage...
-                 * This trick seems to work for text, but figures within the dvi
-                 * file seem to have a mind of their own...
-                 */
-                if (tex1)
-                    free(tex1);
-                tex1 = malloc(strlen(line)+1);
-                strcpy(tex1, line);
-                fprintf(outfd, "%s", line);
-                flush_page ?  memgets(line, LINESIZE-1) :
-                              fgets(line, LINESIZE-1, fd);
-                if (tex2)
-                    free(tex2);
-                tex2 = malloc(strlen(line)+1);
-                strcpy(tex2, line);
-            } 
-        }
+            if (opt_killtrail && (strncmp(line, "%%Trailer", 9) == 0 ||
+                strncmp(line, "%%PSTrailer", 11) == 0)) {
+                fprintf(outfd, "%% %s", line);
+                Debug(DB_PSROFF, "%%post_one_line: found trailer\n", 0);
+                ps_at_trailer = TRUE;
+                return FILE_EOF;
+            }
+            /* For netscape output */
+            if (strncmp(line, "%%EOF", 5) == 0) {
+                fprintf(outfd, "%% %s", line);
+                Debug(DB_PSROFF, "%%post_one_line: Netscape EOF\n", 0);
+                return FILE_EOF;
+            }
+            if (ps_posttype == PS_MPAGE && strncmp(line, "showsheet", 9) == 0)
+                return FILE_CONT;
+            if (ps_posttype == PS_TEX || ps_posttype == PS_TEX2) {
+                if (ps_posttype == PS_TEX2 &&
+                    (strstr(line, "eop\n") || strstr(line, "eop end\n"))) {
+                    fprintf(outfd, "%s", line);
+                    Debug(DB_PSROFF, "%%post_one_line: found TEX eop\n", 0);
+                    return FILE_MORE;
+                }
+                if (strncmp(line, "TeXDict", 7) == 0) {
+                    /*
+                     * Hope all dvi2ps progs work the same:
+                     * capture the TeX init code so we can run it 'manually' for
+                     * every page. This is needed as this code sets up a gstate 
+                     * that conflicts with mpage...
+                     * This trick seems to work for text, but figures within the dvi
+                     * file seem to have a mind of their own...
+                     */
+                    if (tex1)
+                        free(tex1);
+                    tex1 = malloc(strlen(line)+1);
+                    strcpy(tex1, line);
+                    fprintf(outfd, "%s", line);
+                    flush_page ?  memgets(line, LINESIZE-1) :
+                                  fgets(line, LINESIZE-1, fd);
+                    if (tex2)
+                        free(tex2);
+                    tex2 = malloc(strlen(line)+1);
+                    strcpy(tex2, line);
+                } 
+            }
+	}
         fprintf(outfd, "%s", line);
         plcnt++;
 
